/* THIS FILE IS AUTOGENERATED - DO NOT EDIT */

#ifndef mozilla_dom_IDBObjectStoreBinding_h__
#define mozilla_dom_IDBObjectStoreBinding_h__

#include "IDBCursorBinding.h"
#include "js/RootingAPI.h"
#include "jspubtd.h"
#include "mozilla/ErrorResult.h"
#include "mozilla/dom/BindingDeclarations.h"

namespace mozilla {
namespace dom {

struct IDBObjectStoreParametersAtoms;
class NativePropertyHooks;

namespace indexedDB {

class IDBObjectStore;

} // namespace indexedDB

} // namespace dom
} // namespace mozilla

namespace mozilla {
namespace dom {

struct IDBObjectStoreParameters : public MainThreadDictionaryBase
{
  bool mAutoIncrement;
  JS::Value mKeyPath;

  inline IDBObjectStoreParameters()
    : mKeyPath(JS::UndefinedValue())
  {
  }

private:
  IDBObjectStoreParameters(const IDBObjectStoreParameters&) MOZ_DELETE;
  void operator=(const IDBObjectStoreParameters) MOZ_DELETE;

  static bool
  InitIds(JSContext* cx, IDBObjectStoreParametersAtoms* atomsCache);

public:
  bool
  Init(JSContext* cx, JS::Handle<JS::Value> val, const char* sourceDescription = "Value");

  bool
  Init(const nsAString& aJSON);

  bool
  ToObject(JSContext* cx, JS::Handle<JSObject*> parentObject, JS::MutableHandle<JS::Value> rval) const;

  void
  TraceDictionary(JSTracer* trc);
};
struct IDBObjectStoreParametersInitializer : public IDBObjectStoreParameters
{
  IDBObjectStoreParametersInitializer();
};


namespace IDBObjectStoreBinding {

  typedef mozilla::dom::indexedDB::IDBObjectStore NativeType;

  // We declare this as an array so that retrieving a pointer to this
  // binding's property hooks only requires compile/link-time resolvable
  // address arithmetic.  Declaring it as a pointer instead would require
  // doing a run-time load to fetch a pointer to this binding's property
  // hooks.  And then structures which embedded a pointer to this structure
  // would require a run-time load for proper initialization, which would
  // then induce static constructors.  Lots of static constructors.
  extern const NativePropertyHooks sNativePropertyHooks[];
  JSObject*
  DefineDOMInterface(JSContext* aCx, JS::Handle<JSObject*> aGlobal, JS::Handle<jsid> id, bool aDefineOnGlobal);

  const JSClass*
  GetJSClass();

  JSObject*
  Wrap(JSContext* aCx, JS::Handle<JSObject*> aScope, mozilla::dom::indexedDB::IDBObjectStore* aObject, nsWrapperCache* aCache);

  template <class T>
  inline JSObject* Wrap(JSContext* aCx, JS::Handle<JSObject*> aScope, T* aObject)
  {
    return Wrap(aCx, aScope, aObject, aObject);
  }

  void
  CreateInterfaceObjects(JSContext* aCx, JS::Handle<JSObject*> aGlobal, JS::Heap<JSObject*>* aProtoAndIfaceArray, bool aDefineOnGlobal);

  JS::Handle<JSObject*>
  GetProtoObject(JSContext* aCx, JS::Handle<JSObject*> aGlobal);

  JS::Handle<JSObject*>
  GetConstructorObject(JSContext* aCx, JS::Handle<JSObject*> aGlobal, bool aDefineOnGlobal = true);

} // namespace IDBObjectStoreBinding



} // namespace dom
} // namespace mozilla

#endif // mozilla_dom_IDBObjectStoreBinding_h__
